
********************************************************************************
********************************************************************************
************************ Generate Weekly Labor Force ***************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	status_wk_num* ///
	hrs_worked_wk_num* ///
	using "$nlsy79/nlsy79.dta", clear

********************************************************************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

cap drop status_wk_num0000_xrnd
rename status_wk_num*_xrnd lfs*n
rename lfs000*n lfs*
rename lfs00*n lfs*
rename lfs0*n lfs*
rename lfs*n lfs*

cap drop hrs_worked_wk_num0000_xrnd
rename hrs_worked_wk_num*_xrnd hrs_worked*n
rename hrs_worked000*n hrs_worked*
rename hrs_worked00*n hrs_worked*
rename hrs_worked0*n hrs_worked*
rename hrs_worked*n hrs_worked*
	
reshape long lfs hrs_worked, i(id) j(week)
merge m:1 week using "$data/DMY.dta", keep(1 3) keepusing(month year) nogen
sort id week

gen emphelp = 1 if lfs>=7 | lfs==3
	replace emphelp = 0 if lfs==2 | lfs==4 | lfs==5
bys id year: egen wksemp = total(emphelp), missing
cap drop emphelp

save "$temp/lfs_weekly_79.dta", replace
	
******************************** Monthly File **********************************

replace hrs_worked = . if hrs_worked<0
bys id year month: egen hrs_worked_wk = mean(hrs_worked)
bys id year month: egen hrs_worked_max = max(hrs_worked)
bys id year month: egen hrs_worked_min = min(hrs_worked)

gen empstat = 1 if lfs>=7 | lfs==3
	replace empstat = 0 if lfs==2 | lfs==4 | lfs==5
bys id year month: egen lfs_wk = mean(empstat)
bys id year month: egen lfs_max = max(empstat)
bys id year month: egen lfs_min = min(empstat)

bys id year month: drop if _n>1
save "$temp/lfs_monthly_79.dta", replace
	
********************************************************************************
********************************************************************************
*************************** Generate Yearly Poverty ***************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	sampweight_* c_sampweight_* ///
	tnfi_trunc_* famsize_* ///
	using "$nlsy79/nlsy79.dta", clear
	
********************************************************************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

gen miweight = sampweight_1979

reshape long sampweight_ c_sampweight_ tnfi_trunc_ famsize_ ///
	, i(id) j(year)
rename *_ *

// 60 Percent of Median Income

gen relpov = .
forvalues y = 1979/1994 {

	cap drop eqinc
	gen eqinc = tnfi_trunc/sqrt(famsize) if tnfi_trunc>=0 & famsize>0
	_pctile eqinc [aw = sampweight] if year==`y', p(50)
	local n = r(r1)*.60
	replace relpov = 1 if year==`y' & eqinc<`n' & eqinc!=.
	replace relpov = 0 if year==`y' & eqinc>=`n' & eqinc!=.
}

forvalues y = 1996(2)2014 {

	cap drop eqinc
	gen eqinc = tnfi_trunc/sqrt(famsize) if tnfi_trunc>=0 & famsize>0
	_pctile eqinc [aw = sampweight] if year==`y', p(50)
	local n = r(r1)*.60
	replace relpov = 1 if year==`y' & eqinc<`n' & eqinc!=.
	replace relpov = 0 if year==`y' & eqinc>=`n' & eqinc!=.
}

sort id year
save "$temp/povstat_79.dta", replace

********************************************************************************
********************** Generate Child Birth Data File **************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	c1dob_m_xrnd c1dob_y_xrnd c1id_xrnd c1dod_m_xrnd c1dod_y_xrnd c2dob_m_xrnd ///
	c2dob_y_xrnd c2id_xrnd c2dod_m_xrnd c2dod_y_xrnd c3dob_m_xrnd c3dob_y_xrnd ///
	c3id_xrnd c3dod_m_xrnd c3dod_y_xrnd c4dob_m_xrnd c4dob_y_xrnd c4id_xrnd ///
	c4dod_m_xrnd c4dod_y_xrnd c5dob_m_xrnd c5dob_y_xrnd c5id_xrnd c5dod_m_xrnd ///
	c5dod_y_xrnd c6dob_m_xrnd c6dob_y_xrnd c6id_xrnd c6dod_m_xrnd c6dod_y_xrnd ///
	c7dob_m_xrnd c7dob_y_xrnd c7id_xrnd c7dod_m_xrnd c7dod_y_xrnd c8dob_m_xrnd ///
	c8dob_y_xrnd c8id_xrnd c9dob_m_xrnd c9dob_y_xrnd c9id_xrnd c10dob_m_xrnd ///
	c10dob_y_xrnd c10id_xrnd c11dob_m_xrnd c11dob_y_xrnd c11id_xrnd ///
	using "$nlsy79/nlsy79.dta", clear

**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

// Child ID //
local i = 1
foreach x of varlist c1id_xrnd c2id_xrnd c3id_xrnd c4id_xrnd c5id_xrnd c6id_xrnd ///
	c7id_xrnd c8id_xrnd c9id_xrnd c10id_xrnd c11id_xrnd {
	
	clonevar cid`i' = `x'
	cap drop `x'
	
	local i = `i' + 1
}

// Child Year of Birth //
local i = 1
foreach x of varlist c1dob_y_xrnd c2dob_y_xrnd c3dob_y_xrnd c4dob_y_xrnd ///
	c5dob_y_xrnd c6dob_y_xrnd c7dob_y_xrnd c8dob_y_xrnd c9dob_y_xrnd  ///
	c10dob_y_xrnd c11dob_y_xrnd {
	
	clonevar yob`i' = `x'
	cap drop `x'
	
	local i = `i' + 1
}
	
********************* Reshape into Child Long Format ***************************

reshape long cid yob, i(id) j(cnumb)	
label var cnumb "Birth Order of Child"

drop if yob<0
replace yob = 1978 if yob<1978

*************** Generate Person Month (until 30 Data File) *********************

expand 2, gen(newr)
replace cnumb = 0 if newr==1
replace yob = 1978 if newr==1
gen help = -1*cnumb
bys id yob (help): drop if _n>1
cap drop help

replace birthy = birthy + 1900 if birthy>0 & birthy<100
gen age = yob - birthy

rename yob year

********************************************************************************

// cnumb year //
save "$temp/fertility_79.dta", replace	
	
********************************************************************************
*********************** Generate Marrital Status File **************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	marstat_key_* ///
	using "$nlsy79/nlsy79.dta", clear

**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

reshape long marstat_key_, i(id) j(year)

rename marstat_key_ marstat

// year & marstat //
save "$temp/marriage_79.dta", replace

********************************************************************************
********************** Generate Parental Home Data File ************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	hhi_24_1979 hh1_1_1979 hh1_1_1980 hh1_1_1981 hh1_1_1982 hh1_1_1983 ///
	hh1_1_1984 hh1_1_1985 hh1_1_1986 hh1_1_1987 hh1_1_1988 hh1_1_1989 ///
	hh1_1_1990 hh1_1_1991 hh1_1_1992 hh1_1_1993 hh1_1_1994 hh1_1_1996 hh1_1_1998 ///
	hh1_1_2000 hh1_1_2002 hh1_1_2004 hh1_1_2006 hh1_1_2008 hh1_1_2010 hh1_1_2012 ///
	hh1_1_2014 using "$nlsy79/nlsy79.dta", clear
	
**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

replace hh1_1_1979 = 0 if hhi_24_1979==1
cap drop hhi_24_1979

local i = 1979
foreach x of varlist hh1_1_1979 hh1_1_1980 hh1_1_1981 hh1_1_1982 hh1_1_1983 ///
	hh1_1_1984 hh1_1_1985 hh1_1_1986 hh1_1_1987 hh1_1_1988 hh1_1_1989 ///
	hh1_1_1990 hh1_1_1991 hh1_1_1992 hh1_1_1993 hh1_1_1994 {

	clonevar hhtype`i' = `x'
	cap drop `x'
	
	local i = `i' + 1
}

local i = 1996
foreach x of varlist hh1_1_1996 hh1_1_1998 ///
	hh1_1_2000 hh1_1_2002 hh1_1_2004 hh1_1_2006 hh1_1_2008 hh1_1_2010 hh1_1_2012 ///
	hh1_1_2014 {
	
	clonevar hhtype`i' = `x'
	cap drop `x'
	
	local i = `i' + 2	
}
	
******************************** Reshape Data **********************************
	
reshape long hhtype, i(id) j(year)
	
gen lph = .
	label var lph "R Left Parental Home"
	lab def lph 0"In Parental Home" 1"Left Parental Home"
	lab val lph lph

	replace lph = 0 if hhtype==0 & year==1979
		replace lph = 1 if hhtype>0 & year==1979 
	
	forvalues n = 1980/1994 {
		replace lph = 0 if (hhtype==17 | hhtype==19 | hhtype==-4) & year==`n'
		replace lph = 1 if (hhtype>0 & hhtype!=17 & hhtype!=19) & year==`n'
	}
	
forvalues n = 1996(2)2014{
		replace lph = 0 if (hhtype==17 | hhtype==19 | hhtype==-4) & year==`n'
		replace lph = 1 if (hhtype>0 & hhtype!=17 & hhtype!=19) & year==`n'
	}
	
replace lph = -99 if hhtype==-5	

gen lphy = year if lph==1

egen ylph = min(lphy), by(id)	
	bys id (year): replace ylph = -99 if ylph==.
	lab var ylph "Year R Left Parental Home"

// year & lph //
save "$temp/parhome_79.dta", replace

********************************************************************************

********************************************************************************
**************** Generate Respondent Education File ****************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	hgcrev* hgc_2012 hgc_2014 using "$nlsy79/nlsy79.dta", clear

**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender
	
local j = 1979
foreach y in 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 {

	rename hgcrev`y'_`j' hgc_`j'
	local j = `j' + 1
}

local j = 1996
foreach y in 96 98 00 02 04 06 08 10 {
	
	rename hgcrev`y'_`j' hgc_`j'
	local j = `j' + 2
}	
		
******************* Long File for Forwards Replacement *************************
	
reshape long hgc_, i(id) j(year)
rename hgc_ hgc

save "$temp/hgc_79.dta", replace

********************************************************************************

********************************************************************************
****************** Yearly Household Employed & Urban/Rural *********************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	famsize_* urban_rural_* ///
	using "$nlsy79/nlsy79.dta", clear

**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

reshape long famsize_ urban_rural_, i(id) j(year)

rename famsize_ famsize
rename urban_rural_ urban_rural

save "$temp/famsize_79.dta", replace

********************************************************************************
**************************** Occupational Status *******************************
********************************************************************************

use caseid_1979 q1_3_a_m_1979 q1_3_a_y_1979 sample_race_78scrn sample_sex_1979 ///
	cpsocc70_* occall_emp_01_* ///
	using "$nlsy79/nlsy79.dta", clear

**************************** Rename Variables **********************************

rename caseid_1979 id
rename q1_3_a_m_1979 birthm
rename q1_3_a_y_1979 birthy
rename sample_race_78scrn race
rename sample_sex_1979 gender

local y = 1979
foreach x of varlist cpsocc70_1979 cpsocc70_1980 cpsocc70_1981 cpsocc70_1982 ///
	cpsocc70_1983 cpsocc70_1984 cpsocc70_1985 cpsocc70_1986 cpsocc70_1987 ///
	cpsocc70_1988 cpsocc70_1989 cpsocc70_1990 cpsocc70_1991 cpsocc70_1992 ///
	cpsocc70_1993 occall_emp_01_1994 {
	
	rename `x' occ`y'
	local y = `y' + 1
}

local y = 1996
foreach x of varlist occall_emp_01_1996 occall_emp_01_1998 occall_emp_01_2000 ///
	occall_emp_01_2002 occall_emp_01_2004 occall_emp_01_2006 occall_emp_01_2008 ///
	occall_emp_01_2010 occall_emp_01_2012 occall_emp_01_2014 {
	
	rename `x' occ`y'
	local y = `y' + 2
}

reshape long occ, i(id) j(year)

// See Daniel Dorn (https://www.econ.uzh.ch/en/people/faculty/dorn.html) //

merge m:1 occ using "$data/occ1970_occ1990dd.dta", ///
	keepusing(occ1990dd) keep(1 3) nogen
	gen help = occ1990dd

replace occ1990dd = . if year>=2002
replace occ = round(occ/10) if year>=2002
merge m:1 occ using "$data/occ2000_occ1990dd.dta", ///
	keepusing(occ1990dd) keep(1 3 4 5) update nogen
replace occ1990dd = help if occ1990dd==. & help!=.

cap drop occ
recode occ1990dd (003/199 = 1 "Management & Professionals") ///
	(203/391 = 2 "Tachnical, Sales, & Admin. Support") ///
	(402/472 = 3 "Service") ///
	(473/499 = 4 "Farming, Fishing, & Forestry") ///
	(503/699 = 5 "Production, Craft, & Repair") ///
	(703/890 = 6 "Operators, Fabricators, & Laborers") ///
	(903/905 = 7 "Military") (else=.), gen(occ)

save "$temp/occ_79.dta", replace
