
log using $log/relative_FE, text replace	

***************************** RELATIVE POVERTY *********************************
********************************************************************************
********************************************************************************
********************************************************************************

use "$temp/NLSY79_Comb.dta", clear

replace birthy = birthy + 1900
gen age = year - birthy
drop if age<18 | age>50

gen emp = 1 if wksemp>=26 & wksemp!=.
	replace emp = 0 if wksemp<26 & wksemp!=.

gen poor = 1 if wksemp>=26 & wksemp!=. & relpov==1
	replace poor = 0 if wksemp>=26 & wksemp!=. & relpov==0
fre poor

recode lph -99 = .

recode marstat (1 = 1 "Married") (0 2 3 4 6 = 0 "Not Married"), gen(married)
recode marstat 6 3 = 2

rename hrs_worked_wk_yr wkhrs
gen sample = 1 if ///
	!missing(gender, race, hgc, cnumb, married, paredu, famstruct, lph, wkhrs, occ)

tab marstat, gen(marstat_)
	rename marstat_2 marstat1 
	rename marstat_3 marstat2
	
recode hgc (0/11 = 2 "Less than HS") (12 = 1 "HS") (13/20 = 3 "More than HS"), ///
	gen(edu)
	
recode cnumb (0 = 1 "No Children") (1 = 2 "1 Child") (2/11 = 3 "2 plus Children") ///
	, gen(kids) 
	 
sort id year
xtset id age

save "$temp/NLSY79_Comb_Analysis.dta", replace	
	
** Figure 0: Propensity of Risk Factors
tab marstat, gen(mar_)
tab kids, gen(kids_)

******************** Proportion of Entire Sample *******************************

tw lpolyci lph age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(black) clpattern(solid) xtitle("") ytitle("") ///
	|| lpolyci lph age [aw=sampweight] if gender==1 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(black) clpattern(dash) xtitle("") ytitle("") ///
	lcolor(black) lpattern(dot) xscale(range(18 50)) xlabel(18(2)50) ///
	title("Men", size(large)) legend(off) saving($graphs/men, replace)
tw lpolyci lph age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(black) clpattern(solid) xtitle("") ytitle("") ///
	|| lpolyci lph age [aw=sampweight] if gender==2 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(black) clpattern(dash) xtitle("") ytitle("") ///
	lcolor(black) lpattern(dot) xscale(range(18 50)) xlabel(18(2)50) ///
	title("Women", size(large)) legend(off) saving($graphs/women, replace)
gr combine $graphs/men.gph $graphs/women.gph, ///
	r(1) ycomm scheme(plotplainblind) l1title("Parental Home Leaving" "Proportion", size(small)) ///
	saving($graphs/lph_all, replace)

tw lpolyci mar_1 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(turquoise) clpattern(solid) lcolor(black) lpattern(dot) ///
	|| lpolyci mar_2 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(sea) clpattern(solid) lcolor(sea) lpattern(dot) ///
	|| lpolyci mar_3 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(reddish) clpattern(solid) lcolor(reddish) lpattern(dot) ///
	|| lpolyci mar_1 age [aw=sampweight] if gender==1 & poor==1, ///
	ciplot(rline) clcolor(turquoise) clpattern(dash) lcolor(black) lpattern(dot) ///
	|| lpolyci mar_2 age [aw=sampweight] if gender==1 & poor==1, ///
	ciplot(rline) clcolor(sea) clpattern(dash) lcolor(sea) lpattern(dot) ///
	|| lpolyci mar_3 age [aw=sampweight] if gender==1 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(reddish) clpattern(dash) lcolor(reddish) lpattern(dot) ///
	xtitle("") ytitle("") xscale(range(18 50)) xlabel(18(2)50) ///
	legend(off) ///
	saving($graphs/men, replace)
tw lpolyci mar_1 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(turquoise) clpattern(solid) lcolor(black) lpattern(dot) ///
	|| lpolyci mar_2 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(sea) clpattern(solid) lcolor(sea) lpattern(dot) ///
	|| lpolyci mar_3 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(reddish) clpattern(solid) lcolor(reddish) lpattern(dot) ///
	|| lpolyci mar_1 age [aw=sampweight] if gender==2 & poor==1, ///
	ciplot(rline) clcolor(turquoise) clpattern(dash) lcolor(black) lpattern(dot) ///
	|| lpolyci mar_2 age [aw=sampweight] if gender==2 & poor==1, ///
	ciplot(rline) clcolor(sea) clpattern(dash) lcolor(sea) lpattern(dot) ///
	|| lpolyci mar_3 age [aw=sampweight] if gender==2 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(reddish) clpattern(dash) lcolor(reddish) lpattern(dot) ///
	xtitle("") ytitle("") xscale(range(18 50)) xlabel(18(2)50) ///
	legend(off) ///
	saving($graphs/women, replace)	
gr combine $graphs/men.gph $graphs/women.gph, ///
	r(1) ycomm scheme(plotplainblind) l1title("Marital Status" "Proportion", size(small)) ///
	saving($graphs/marstat_all, replace)

tw lpolyci kids_1 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(vermillion) clpattern(solid) lcolor(black) lpattern(dot) ///
	|| lpolyci kids_2 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(sky) clpattern(solid) lcolor(sea) lpattern(dot) ///
	|| lpolyci kids_3 age [aw=sampweight] if gender==1, ///
	ciplot(rline) clcolor(orangebrown) clpattern(solid) lcolor(reddish) lpattern(dot) ///
	|| lpolyci kids_1 age [aw=sampweight] if gender==1 & poor==1, ///
	ciplot(rline) clcolor(vermillion) clpattern(dash) lcolor(black) lpattern(dot) ///
	|| lpolyci kids_2 age [aw=sampweight] if gender==1 & poor==1, ///
	ciplot(rline) clcolor(sky) clpattern(dash) lcolor(sea) lpattern(dot) ///
	|| lpolyci kids_3 age [aw=sampweight] if gender==1 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(orangebrown) clpattern(dash) lcolor(reddish) lpattern(dot) ///
	xtitle("") ytitle("") xscale(range(18 50)) xlabel(18(2)50) ///
	legend(off) ///
	saving($graphs/men, replace)
tw lpolyci kids_1 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(vermillion) clpattern(solid) lcolor(black) lpattern(dot) ///
	|| lpolyci kids_2 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(sky) clpattern(solid) lcolor(sea) lpattern(dot) ///
	|| lpolyci kids_3 age [aw=sampweight] if gender==2, ///
	ciplot(rline) clcolor(orangebrown) clpattern(solid) lcolor(reddish) lpattern(dot) ///	
	|| lpolyci kids_1 age [aw=sampweight] if gender==2 & poor==1, ///
	ciplot(rline) clcolor(vermillion) clpattern(dash) lcolor(black) lpattern(dot) ///
	|| lpolyci kids_2 age [aw=sampweight] if gender==2 & poor==1, ///
	ciplot(rline) clcolor(sky) clpattern(dash) lcolor(sea) lpattern(dot) ///
	|| lpolyci kids_3 age [aw=sampweight] if gender==2 & poor==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(orangebrown) clpattern(dash) lcolor(reddish) lpattern(dot) ///
	xtitle("") ytitle("") xscale(range(18 50)) xlabel(18(2)50) ///
	legend(off) ///
	saving($graphs/women, replace)	
gr combine $graphs/men.gph $graphs/women.gph, ///
	r(1) ycomm scheme(plotplainblind) l1title("Fertility" "Proportion", size(small)) ///
	saving($graphs/kids_all, replace)	
	
gr combine $graphs/lph_all.gph $graphs/marstat_all.gph $graphs/kids_all.gph, ///
	r(3) ycomm scheme(plotplainblind) ///
	saving($graphs/Risks_All, replace)
	
****************** Figure 1: Propensity of Working Poor ************************
drop if poor==.

tw lpolyci poor age [aw=sampweight] if gender==1, scheme(plotplainblind) ///
	ciplot(rline) clcolor(black) clpattern(solid) xtitle("") ytitle("") ///
	lcolor(black) lpattern(dot) xscale(range(18 50)) xlabel(18(2)50) ///
	title("Men", size(large)) legend(off) saving($graphs/men, replace)
tw lpolyci poor age [aw=sampweight] if gender==2, scheme(plotplainblind) ///
	ciplot(rline) clcolor(black) clpattern(solid) xtitle("") ytitle("") ///
	lcolor(black) lpattern(dot) xscale(range(18 50)) xlabel(18(2)50) ///
	title("Women", size(large)) legend(off) saving($graphs/women, replace)
gr combine $graphs/men.gph $graphs/women.gph, ///
	r(1) ycomm scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Proportion", size(small)) ///
	saving($graphs/entire, replace)

************************** LEFT THE PARENTAL HOME ******************************
********************************************************************************

*** Overall by Gender
xtreg poor i.lph##i.age i.edu i.marstat i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==1, fe vce(cluster id)	
margins, dydx(lph) at(age=(18(1)50)) post
est store men

xtreg poor i.lph##i.age i.edu i.marstat i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==2, fe vce(cluster id)	
margins, dydx(lph) at(age=(18(1)50)) post
est store women

***
coefplot (men, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.8 .6)) ylabel(-.8(.2).6) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Men", size(large)) saving($graphs/lph_men_FE, replace)
coefplot (women, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.8 .6)) ylabel(-.8(.2).6) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Women", size(large)) saving($graphs/lph_women_FE, replace)

gr combine $graphs/lph_men_FE.gph $graphs/lph_women_FE.gph, ///
	scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Estimated Coefficient", size(small)) r(1) ///
	saving($graphs/lph_relative_FE, replace)

************************ Marital Status - Married ******************************
********************************************************************************

*** Overall by Gender
xtreg poor lph i.marstat##i.age i.edu i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==1, fe vce(cluster id)	
margins, dydx(1.marstat) at(age=(18(1)50)) post
est store men

xtreg poor lph i.marstat##i.age i.edu i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==2, fe vce(cluster id)	
margins, dydx(1.marstat) at(age=(18(1)50)) post
est store women

***
coefplot (men, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.4 .8)) ylabel(-.4(.2).8) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Men", size(large)) saving($graphs/married_men_FE, replace)
coefplot (women, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.4 .8)) ylabel(-.4(.2).8) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Women", size(large)) saving($graphs/married_women_FE, replace)

gr combine $graphs/married_men_FE.gph $graphs/married_women_FE.gph, ///
	scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Estimated Coefficient", size(small)) r(1) ///
	saving($graphs/married_relative_FE, replace)
	
************************ Marital Status - Seperated ****************************
********************************************************************************

*** Overall by Gender
xtreg poor lph ib1.marstat##i.age i.edu i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==1, fe vce(cluster id)	
margins, dydx(2.marstat) at(age=(18(1)50)) post
est store men

xtreg poor lph ib1.marstat##i.age i.edu i.kids  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==2, fe vce(cluster id)	
margins, dydx(2.marstat) at(age=(18(1)50)) post
est store women

***
coefplot (men, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.6 .6)) ylabel(-.6(.2).6) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Men", size(large)) saving($graphs/seperated_men_FE, replace)
coefplot (women, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.6 .6)) ylabel(-.6(.2).6) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Women", size(large)) saving($graphs/seperated_women_FE, replace)

gr combine $graphs/seperated_men_FE.gph $graphs/seperated_women_FE.gph, ///
	scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Estimated Coefficient", size(small)) r(1) ///
	saving($graphs/seperated_relative_FE, replace)
	
**************************** NUMBER OF CHILDREN (2, 3) **************************
********************************************************************************

*** Overall by Gender
xtreg poor lph ib1.kids##i.age i.edu i.marstat  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==1, fe vce(cluster id)	
margins, dydx(2.kids) at(age=(18(1)50)) post
est store men2

xtreg poor lph ib1.kids##i.age i.edu i.marstat  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==2, fe vce(cluster id)	
margins, dydx(2.kids) at(age=(18(1)50)) post
est store women2

coefplot (men2, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.2 .8)) ylabel(-.2(.2).8) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Men", size(large)) ///
	saving($graphs/kids2_men_FE, replace)
	
coefplot (women2, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.2 .8)) ylabel(-.2(.2).8) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Women", size(large)) saving($graphs/kids2_women_FE, replace)

gr combine $graphs/kids2_men_FE.gph $graphs/kids2_women_FE.gph, ///
	scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Estimated Coefficient", size(small)) r(1) ///
	saving($graphs/kids2_relative_FE, replace)	

*** Overall by Gender
xtreg poor lph ib1.kids##i.age i.edu i.marstat  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==1, fe vce(cluster id)	
margins, dydx(3.kids) at(age=(18(1)50)) post
est store men3

xtreg poor lph ib1.kids##i.age i.edu i.marstat  ///
	wkhrs urban_rural i.occ [pw = miweight] if gender==2, fe vce(cluster id)	
margins, dydx(3.kids) at(age=(18(1)50)) post
est store women3

coefplot (men3, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.2 1)) ylabel(-.2(.2)1) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Men", size(large)) ///
	saving($graphs/kids3_men_FE, replace)
	
coefplot (women3, lcolor(black) ciopts(recast(rline) lpattern(shortdash) lcolor(black))), ///
	scheme(plotplainblind) vertical  ///
	recast(line) yline(0, lcolor(reddish)) ///
	lpattern(solid) yscale(range(-.2 1)) ylabel(-.2(.2)1) ///
	xscale(range(1 33)) xlabel(1"18" 3"20" 5"22" 7"24" ///
	9"26" 11"28" 13"30" 15"32" 17"34" 19"36" ///
	21"38" 23"40" 25"42" 27"44" 29"46" 31"48" 33"50") ///
	title("Women", size(large)) saving($graphs/kids3_women_FE, replace)

gr combine $graphs/kids3_men_FE.gph $graphs/kids3_women_FE.gph, ///
	scheme(plotplainblind) ///
	b1title("Age", size(small)) l1title("Estimated Coefficient", size(small)) r(1) ///
	saving($graphs/kids3_relative_FE, replace)	

*********
log close


